@@ -1,15 +1,24 @@
 =head1 NAME
 
-Databases - List available MLST databases
+Bio::MLST::Databases
 
 =head1 SYNOPSIS
 
+List available MLST databases
+
+=head1 DESCRIPTION
+
 use Bio::MLST::Databases;
 
 my $mlst_dbs = Bio::MLST::Databases->new(
   base_directory => '/path/to/databases',
 );
 $mlst_dbs->print_db_list;
+
+=head1 CONTACT
+
+path-help@sanger.ac.uk
+
 =cut
 
 package Bio::MLST::Databases;
